@@ -10,6 +10,9 @@ class GazetteerTermExtractor:
             self.en_model = spacy.load(spacy_model, disable=['ner', 'tagger', 'parser'])
             self.tokenize = self._spacy_tokenize
             self.tokenize_spans = self._spacy_tokenize_spans
+        else:
+            self.tokenize = tokenize
+            self.tokenize_spans = tokenize_spans
 
         self.terms_by_lengths = {}
         for term in term_list:
